import{_ as u}from"./ItemsListing.vue_vue_type_style_index_0_lang-38bc2f50.js";import{l as c,r as l,o as f,H as e,ao as o,b as _,v as d,x as b,M as m,ap as r}from"./index-dcf0de03.js";import"./ListviewItem-2c46c8ee.js";import"./MediaItemThumb.vue_vue_type_style_index_0_lang-b38d9ae1.js";import"./ListItem-6dad7331.js";import"./VBtn-a0da5efe.js";import"./VMenu-3bdd1b96.js";import"./index-0afee102.js";import"./VListItem-943ee224.js";import"./VCheckboxBtn-d54a899d.js";import"./VCard-111cabcf.js";/* empty css                             */import"./PanelviewItem.vue_vue_type_style_index_0_lang-44df1bef.js";import"./contextmenu-ec34ccac.js";import"./eventbus-d154090d.js";import"./Alert-eb81bdeb.js";import"./Container-d623752d.js";/* empty css              */import"./VToolbar-dfba6de4.js";import"./VTextField-f81f9175.js";import"./VBadge-8be61727.js";import"./VRow-73379099.js";const W=c({__name:"LibraryAlbums",setup(y){const n=l([]),i=l(!1);f(()=>{const t=e.subscribe_multi([o.MEDIA_ITEM_ADDED,o.MEDIA_ITEM_UPDATED,o.MEDIA_ITEM_DELETED],a=>{var s;(s=a.object_id)!=null&&s.startsWith("library://artist")&&(i.value=!0)});_(t)});const p=async function(t){if(t.refresh){for(e.startSync([m.ALBUM]),await r(250);e.syncTasks.value.length>0&&e.syncTasks.value.filter(a=>a.media_types.includes(m.ALBUM)).length!=0;)await r(500);await r(500)}return i.value=!1,await e.getLibraryAlbums(t.favoritesOnly||void 0,t.search,t.limit,t.offset,t.sortBy)};return(t,a)=>(d(),b(u,{itemtype:"albums",items:n.value,"show-provider":!1,"show-favorites-only-filter":!0,"load-data":p,"sort-keys":["sort_name","timestamp_added DESC","sort_artist","year"],"update-available":i.value,title:t.$t("albums"),"allow-key-hooks":!0,"show-search-button":!0},null,8,["items","update-available","title"]))}});export{W as default};
