import{c as n,p as r,g as c,u as i,j as l,v as p,x as u,W as d,B as f,k as m,y as _,Z as C}from"./index-dcf0de03.js";import{a as v}from"./ListItem-6dad7331.js";/* empty css              */import{a as y,d as P,i as g}from"./VBtn-a0da5efe.js";const k={setup(e,s){const t=n(()=>({}));return{containerProps:n(()=>({...t.value,...s.attrs}))}}};const V=r({fluid:{type:Boolean,default:!1},...y(),...P()},"VContainer"),$=c()({name:"VContainer",props:V(),setup(e,s){let{slots:t}=s;const{rtlClasses:a}=i();return g(()=>l(e.tag,{class:["v-container",{"v-container--fluid":e.fluid},a.value,e.class],style:e.style},t)),{}}});function x(e,s,t,a,B,h){return p(),u($,m(a.containerProps,{class:"container",fluid:""}),d({_:2},[f(e.$slots,(R,o)=>({name:o,fn:_(()=>[C(e.$slots,o)])}))]),1040)}const F=v(k,[["render",x]]);export{F as C};
