import{l as f,L as d,r as m,o as _,H as a,ao as s,b as y,v as b,x as v,M as i,ap as n}from"./index-dcf0de03.js";import{_ as h}from"./ItemsListing.vue_vue_type_style_index_0_lang-38bc2f50.js";import"./ListviewItem-2c46c8ee.js";import"./MediaItemThumb.vue_vue_type_style_index_0_lang-b38d9ae1.js";import"./ListItem-6dad7331.js";import"./VBtn-a0da5efe.js";import"./VMenu-3bdd1b96.js";import"./index-0afee102.js";import"./VListItem-943ee224.js";import"./VCheckboxBtn-d54a899d.js";import"./VCard-111cabcf.js";/* empty css                             */import"./PanelviewItem.vue_vue_type_style_index_0_lang-44df1bef.js";import"./contextmenu-ec34ccac.js";import"./eventbus-d154090d.js";import"./Alert-eb81bdeb.js";import"./Container-d623752d.js";/* empty css              */import"./VToolbar-dfba6de4.js";import"./VTextField-f81f9175.js";import"./VBadge-8be61727.js";import"./VRow-73379099.js";const q=f({__name:"LibraryTracks",setup(k){const{t:l}=d(),u=m([]),r=m(!1);_(()=>{const t=a.subscribe_multi([s.MEDIA_ITEM_ADDED,s.MEDIA_ITEM_UPDATED,s.MEDIA_ITEM_DELETED],e=>{var o;(o=e.object_id)!=null&&o.startsWith("library://track")&&(r.value=!0)});y(t)});const c=async function(t){if(t.favoritesOnly=t.favoritesOnly||void 0,t.refresh){for(a.startSync([i.TRACK]),await n(250);a.syncTasks.value.length>0&&a.syncTasks.value.filter(e=>e.media_types.includes(i.TRACK)).length!=0;)await n(500);await n(500)}return r.value=!1,await a.getLibraryTracks(t.favoritesOnly,t.search,t.limit,t.offset,t.sortBy)},p=async function(){const t=prompt(l("enter_url"));t&&a.getItem(i.TRACK,t,"url").then(e=>{const o=prompt(l("enter_name"),e.name);e.name=o||e.name,a.addItemToLibrary(e).then(()=>r.value=!0)}).catch(e=>alert(e))};return(t,e)=>(b(),v(h,{itemtype:"tracks",items:u.value,"show-provider":!1,"show-favorites-only-filter":!0,"show-track-number":!1,"load-data":c,"sort-keys":["sort_name","timestamp_added DESC","sort_artist","duration"],"show-album":!1,"update-available":r.value,title:t.$t("tracks"),"show-search-button":!0,"allow-key-hooks":!0,"context-menu-items":[{label:"add_url_item",labelArgs:[],action:()=>{p()},icon:"mdi-link-plus"}]},null,8,["items","update-available","title","context-menu-items"]))}});export{q as default};
