import{_ as u,f}from"./ItemsListing.vue_vue_type_style_index_0_lang-38bc2f50.js";import{_ as v,a as _}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-1829229a.js";import{l as h,r as w,w as y,v as a,A as V,j as k,x as m,D as n,I,H as s,aq as g}from"./index-dcf0de03.js";import"./ListviewItem-2c46c8ee.js";import"./MediaItemThumb.vue_vue_type_style_index_0_lang-b38d9ae1.js";import"./ListItem-6dad7331.js";import"./VBtn-a0da5efe.js";import"./VMenu-3bdd1b96.js";import"./index-0afee102.js";import"./VListItem-943ee224.js";import"./VCheckboxBtn-d54a899d.js";import"./VCard-111cabcf.js";/* empty css                             */import"./PanelviewItem.vue_vue_type_style_index_0_lang-44df1bef.js";import"./contextmenu-ec34ccac.js";import"./eventbus-d154090d.js";import"./Alert-eb81bdeb.js";import"./Container-d623752d.js";/* empty css              */import"./VToolbar-dfba6de4.js";import"./VTextField-f81f9175.js";import"./VBadge-8be61727.js";import"./VRow-73379099.js";import"./layout-087be267.js";import"./VDialog-ccbfddc9.js";const R=I("br",null,null,-1),W=h({__name:"RadioDetails",props:{itemId:{},provider:{}},setup(p){const i=p,e=w(),l=async function(){e.value=await s.getRadio(i.itemId,i.provider)};y(()=>i.itemId,t=>{t&&l()},{immediate:!0});const d=async function(t){const o=[];if(i.provider=="library"){const r=await s.getRadioVersions(i.itemId,i.provider);o.push(...r)}for(const r of g(e.value)){const c=await s.getRadioVersions(r.item_id,r.provider_instance);o.push(...c)}return f(o,t)};return(t,o)=>(a(),V("section",null,[k(v,{item:e.value},null,8,["item"]),e.value?(a(),m(u,{key:0,itemtype:"radioversions","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library":!1,"show-radio-number":!1,"show-duration":!1,"load-data":d,"sort-keys":["provider","sort_name"],title:t.$t("other_versions"),"hide-on-empty":!0,checksum:t.provider+t.itemId},null,8,["parent-item","title","checksum"])):n("",!0),R,e.value?(a(),m(_,{key:1,"item-details":e.value},null,8,["item-details"])):n("",!0)]))}});export{W as default};
